import { Injectable } from '@angular/core';
import { Router, CanActivate } from '@angular/router';
import { UserService } from '../services';
import { NotificationService } from '../../services';

@Injectable()
export class UnauthenticatedGuard implements CanActivate {

  constructor(
    private _userService: UserService,
    private _router: Router,
    private _notificationService: NotificationService,
  ) { }

  // This guard is used to restrict the access to unauthenticated user on particular routes
  // example: login, signup, resetPassword...
  // It also notify the user that he is already logged in
  canActivate(): boolean {
    if (this._userService.userIsSignedIn) {
      this._router.navigate(['/']);
      this._notificationService.notify({
        type: 'warning',
        message: 'Vous ne pouvez pas accéder à cette page lorsque vous êtes déjà authentifié.',
      });
      return false;
    }
    return true;
  }
}
